from provenaclient.provena_client import Auth, Client, Settings 

settings = Settings(
    domain = "mds.gbrrestoration.org"
)

auth = Auth(
    settings = settings
)

client = Client(
    auth = auth, 
    settings = settings
)


from dataclasses import dataclass

@dataclass
class Settings:
    domain: str
    
class Auth:
    def __init__(self, settings: Settings):
        self.settings = settings

class Client:
    def __init__(self, auth: Auth, settings: Settings):
        self.auth = auth
        self.settings = settings

